(*
    Options dialog for auto-diff
    Copyright (c) 2002-2003,2004 Alessandro Scotti
    www.ascotti.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
unit DiffAutoPopup;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, ExtCtrls;

type
  TAutoPopupMode = ( pmDoc1, pmDoc2 );

type
  TFormDiffAutoPopup = class(TForm)
    sbCopyLeft: TSpeedButton;
    sbDeleteBlock: TSpeedButton;
    sbCopyRight: TSpeedButton;
    sbCopySingleLeft: TSpeedButton;
    sbCopySingleRight: TSpeedButton;
    TimerHide: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure sbCopyLeftClick(Sender: TObject);
    procedure TimerHideTimer(Sender: TObject);
  private
    { Private declarations }
    FLine: integer;
  public
    { Public declarations }
    procedure Popup( const P: TPoint; Mode: TAutoPopupMode; Line: integer );
  end;

var
  FormDiffAutoPopup: TFormDiffAutoPopup;

implementation

uses
  Main;

{$R *.DFM}

procedure TFormDiffAutoPopup.FormCreate(Sender: TObject);
begin
  SetWindowLong( Self.Handle, GWL_STYLE, WS_BORDER or (GetWindowLong(Self.Handle, GWL_STYLE ) and not WS_CAPTION) );
  sbCopyRight.Left := sbCopyLeft.Left;
  sbCopySingleRight.Left := sbCopyLeft.Left;
  Width := 1 + sbCopyLeft.Width + sbCopyLeft.Left * 2;
  Height := 1 + sbCopyLeft.Top + sbDeleteBlock.Top + sbDeleteBlock.Height;
end;

procedure TFormDiffAutoPopup.Popup( const P: TPoint; Mode: TAutoPopupMode; Line: integer );
begin
  FLine := Line;
  sbCopyLeft.Visible := Mode = pmDoc2;
  sbCopyRight.Visible := Mode = pmDoc1;
  sbCopySingleLeft.Visible := Mode = pmDoc2;
  sbCopySingleRight.Visible := Mode = pmDoc1;
  Left := P.X;
  Top := P.Y;
  Show;
  TimerHide.Enabled := true;
end;

procedure TFormDiffAutoPopup.sbCopyLeftClick(Sender: TObject);
var
  A: TChangeBlockAction;
begin
  TimerHide.Enabled := false;
  Hide;
  case (Sender as TSpeedButton).Tag of
    0: A := baCopyToDoc1;
    1: A := baCopyToDoc2;
    2: A := baCopySingleToDoc1;
    3: A := baCopySingleToDoc2;
    4: if( sbCopyLeft.Visible ) then A := baDeleteFromDoc2 else A := baDeleteFromDoc1;
    else Exit;
  end;
  MainForm.ChangeBlock( FLine, A );
end;

// Used to hide the popup window if the mouse goes too far from it
procedure TFormDiffAutoPopup.TimerHideTimer(Sender: TObject);
const
  MouseThreshold = 16;
var
  P: TPoint;
  R: TRect;
begin
  if( Visible ) then begin
    R := BoundsRect;
    InflateRect( R, MouseThreshold, MouseThreshold);
    GetCursorPos( P );
    if not PtInRect( R, P ) then begin
      TimerHide.Enabled := false;
      Hide;
    end;
  end
  else begin
    TimerHide.Enabled := false;
  end;
end;

end.
