(*
    Undo item
    Copyright (c) 2002-2003,2004 Alessandro Scotti
    www.ascotti.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
unit DiffUndoBuffer;

interface

uses
  Classes, DiffTypes, UndoRedo;

type
  TDiffUndoItem = class(TUndoRedoItem)
  private
    FOldMode: TDiffLineMode;
    FNewMode: TDiffLineMode;
    FLineFrom: integer;
    FLineTo: integer;
    FFlags: integer;
  public
    constructor Create( AOldMode, ANewMode: TDiffLineMode; ALineFrom, ALineTo, AFlags: integer );
    destructor Destroy; override;

    property OldMode: TDiffLineMode read FOldMode write FOldMode;
    property NewMode: TDiffLineMode read FNewMode write FNewMode;
    property LineFrom: integer read FLineFrom write FLineFrom;
    property LineTo: integer read FLineTo write FLineTo;
    property Flags: integer read FFlags write FFlags;
  end;

  TEditDiffDocUndoItem = class(TUndoRedoItem)
  private
    FDiffs: TList;
    FMode: TDiffLineMode;
    FFlags: integer;
  public
    constructor Create( AList: TList; AMode: TDiffLineMode; AFlags: integer );
    destructor Destroy; override;

    property Diffs: TList read FDiffs write FDiffs;
    property Mode: TDiffLineMode read FMode write FMode;
    property Flags: integer read FFlags write FFlags;
  end;

implementation

uses
  DiffEngine;

constructor TDiffUndoItem.Create( AOldMode, ANewMode: TDiffLineMode; ALineFrom, ALineTo, AFlags: integer );
begin
  inherited Create;
  FOldMode := AOldMode;
  FNewMode := ANewMode;
  FLineFrom := ALineFrom;
  FLineTo := ALineTo;
  FFlags := AFlags;
end;

destructor TDiffUndoItem.Destroy;
begin
  inherited Destroy;
end;

constructor TEditDiffDocUndoItem.Create( AList: TList; AMode: TDiffLineMode; AFlags: integer );
begin
  FDiffs := AList;
  FMode := AMode;
  FFlags := AFlags;
end;

destructor TEditDiffDocUndoItem.Destroy;
begin
  TDiffEngine.FreeDiffList( FDiffs );
  inherited Destroy;
end;

end.
