(*
    LCS - A study for a simple differencing program
    Options window
    Copyright (c) 2002-2003,2004 Alessandro Scotti
    www.ascotti.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
unit FormOptions;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls,
  Config, Options, ComCtrls;

type
  TOptionsForm = class(TForm)
    ButtonCancel: TButton;
    ButtonOk: TButton;
    PageOptions: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    LabelTabSize: TLabel;
    ChkRestoreWindowSettings: TCheckBox;
    TxtColorNormalText: TStaticText;
    TxtColorOnlyDoc1: TStaticText;
    TxtColorOnlyDoc2: TStaticText;
    TxtColorChangedLine: TStaticText;
    TxtColorMissingLine: TStaticText;
    TxtColorLineNumbers: TStaticText;
    ButtonBrowseNormalText: TButton;
    ButtonBrowseOnlyDoc1: TButton;
    ButtonBrowseOnlyDoc2: TButton;
    ButtonBrowseChangedLine: TButton;
    ButtonBrowseMissingLine: TButton;
    ButtonBrowseLineNumbers: TButton;
    ButtonDefaultNormalText: TButton;
    ButtonDefaultOnlyDoc1: TButton;
    ButtonDefaultOnlyDoc2: TButton;
    ButtonDefaultChangedLine: TButton;
    ButtonDefaultMissingLine: TButton;
    ButtonDefaultLineNumbers: TButton;
    ColorDialog: TColorDialog;
    Differencing: TTabSheet;
    chkIgnoreBlanks: TCheckBox;
    ChkIgnoreCase: TCheckBox;
    LabelPopupMargin: TLabel;
    LabelDoubleClick: TLabel;
    ComboDoubleClick: TComboBox;
    CboBackupMode: TComboBox;
    LabelBackupMode: TLabel;
    CboTabSize: TComboBox;
    CboAutoPopup: TComboBox;
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure FormActivate(Sender: TObject);
    procedure ButtonBrowseNormalTextClick(Sender: TObject);
    procedure ButtonDefaultNormalTextClick(Sender: TObject);
  private
    { Private declarations }
    FOptions: TAppOptions;
    function ColorFromIndex( AIndex: integer ): TStaticText;
  public
    { Public declarations }
    procedure SetOptions( const Options: TAppOptions );
    procedure GetOptions( var Options: TAppOptions );
  end;

var
  OptionsForm: TOptionsForm;

implementation

uses
  Utils;

{$R *.DFM}

const
  DefaultColors: array[ 0..5 ] of integer = (
    DefaultColorDefault,
    DefaultColorOnlyDoc1,
    DefaultColorOnlyDoc2,
    DefaultColorChangedLine,
    DefaultColorMissingLine,
    DefaultColorLineNumber
  );

procedure TOptionsForm.SetOptions( const Options: TAppOptions );
begin
  FOptions := Options;
  case Options.TabSize.Value of
    0: CboTabSize.ItemIndex := 0;
    2, 3, 4, 5, 6, 7, 8: CboTabSize.ItemIndex := Options.TabSize.Value-1;
    else CboTabSize.ItemIndex := CboTabSize.Items.Count-1;
  end;
  case Options.PopupMargin.Value of
     0:  CboAutoPopup.ItemIndex := 0;
    24:  CboAutoPopup.ItemIndex := 2;
    32:  CboAutoPopup.ItemIndex := 3;
    else CboAutoPopup.ItemIndex := 1;
  end;
  CboBackupMode.ItemIndex := Options.BackupMode.Value;
  ChkIgnoreBlanks.Checked := Options.IgnoreBlanks.Value;
  ChkIgnoreCase.Checked := Options.IgnoreCase.Value;
  ChkRestoreWindowSettings.Checked := FOptions.RestoreWindowSettings.Value;
  TxtColorNormalText.Color := FOptions.ColorDefault.Value;
  TxtColorOnlyDoc1.Color := FOptions.ColorOnlyDoc1.Value;
  TxtColorOnlyDoc2.Color := FOptions.ColorOnlyDoc2.Value;
  TxtColorChangedLine.Color := FOptions.ColorChangedLine.Value;
  TxtColorMissingLine.Color := FOptions.ColorMissingLine.Value;
  TxtColorLineNumbers.Color := FOptions.ColorLineNumber.Value;
  ComboDoubleClick.ItemIndex := ChooseInteger( FOptions.DblClickOnRightFileDeletes.Value, 1, 0 );
end;

procedure TOptionsForm.GetOptions( var Options: TAppOptions );
begin
  Options := FOptions;
end;

procedure TOptionsForm.FormCloseQuery(Sender: TObject;
  var CanClose: Boolean);
begin
  try
    FOptions.TabSize.Value := 0;
    if( CboTabSize.ItemIndex > 0 ) then
      FOptions.TabSize.Value := StrToInt( CboTabSize.Items[CboTabSize.ItemIndex] );
    case CboAutoPopup.ItemIndex of
      1:   FOptions.PopupMargin.Value := 16;
      2:   FOptions.PopupMargin.Value := 24;
      3:   FOptions.PopupMargin.Value := 32;
      else FOptions.PopupMargin.Value := 0;
    end;
    FOptions.IgnoreBlanks.Value := ChkIgnoreBlanks.Checked;
    FOptions.IgnoreCase.Value := ChkIgnoreCase.Checked;
    FOptions.BackupMode.Value := CboBackupMode.ItemIndex;
    FOptions.RestoreWindowSettings.Value := ChkRestoreWindowSettings.Checked;
    FOptions.DblClickOnRightFileDeletes.Value := ComboDoubleClick.ItemIndex = 1;
    FOptions.ColorDefault.Value := TxtColorNormalText.Color;
    FOptions.ColorOnlyDoc1.Value := TxtColorOnlyDoc1.Color;
    FOptions.ColorOnlyDoc2.Value := TxtColorOnlyDoc2.Color;
    FOptions.ColorChangedLine.Value := TxtColorChangedLine.Color;
    FOptions.ColorMissingLine.Value := TxtColorMissingLine.Color;
    FOptions.ColorLineNumber.Value := TxtColorLineNumbers.Color;
  except
    CanClose := false;
    MessageBox( Handle, 'Invalid option value(s)', 'Options', MB_OK or MB_ICONERROR );
  end;
end;

procedure TOptionsForm.FormActivate(Sender: TObject);
begin
  PageOptions.ActivePageIndex := 0;
end;

function TOptionsForm.ColorFromIndex( AIndex: integer ): TStaticText;
begin
  Result := nil;
  case AIndex of
    0: Result := TxtColorNormalText;
    1: Result := TxtColorOnlyDoc1;
    2: Result := TxtColorOnlyDoc2;
    3: Result := TxtColorChangedLine;
    4: Result := TxtColorMissingLine;
    5: Result := TxtColorLineNumbers;
  end;
end;

procedure TOptionsForm.ButtonBrowseNormalTextClick(Sender: TObject);
var
  E: TStaticText;
begin
  E := ColorFromIndex( (Sender as TButton).Tag );
  ColorDialog.Color := E.Color;
  if( ColorDialog.Execute ) then begin
    E.Color := ColorDialog.Color;
  end;
end;

procedure TOptionsForm.ButtonDefaultNormalTextClick(Sender: TObject);
var
  T: integer;
begin
  T := (Sender as TButton).Tag;
  ColorFromIndex(T).Color := DefaultColors[T];
end;

end.
